bayespy.inference.vmp.transformations.RotateMultiple.__init__
=============================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateMultiple.__init__